@@ -194,8 +194,8 @@ def ptn_rnn_decoder(cell,
             return tf.gather_nd(enc_outputs, input_index_pairs)
 
         def custom_sample_from_logits(logits):
-            _, top4 = tf.nn.top_k(logits, 5)
-            prob = tf.constant([[5, 4, 3, 2, 1]], dtype=tf.float32)
+            _, top4 = tf.nn.top_k(logits, 8)
+            prob = tf.constant([[70, 9, 6, 5, 4, 3, 2, 1]], dtype=tf.float32)
             sample = tf.cast(tf.multinomial(logits=tf.tile(prob, [batch_size, 1]), num_samples=1), dtype=tf.int32)
             sampled_idx = tf.gather_nd(top4, tf.concat([tf.range(batch_size)[:, tf.newaxis], sample], axis=-1))
 
@@ -304,7 +304,8 @@ def ptn_rnn_decoder(cell,
                                              tf.ones([batch_size, seq_length], dtype=tf.bool),
                                              tf.tile(tf.math.logical_not(taohua_mask)[tf.newaxis, :], [batch_size, 1]))
 
-                taohua_ajust_mask = tf.less(tf.random_uniform([batch_size], 0, 1, dtype=tf.float32), 0.2)
+                # taohua_ajust_mask = tf.less(tf.random_uniform([batch_size], 0, 1, dtype=tf.float32), 0.2)
+                taohua_ajust_mask = tf.less(tf.random_uniform([batch_size], 0, 1, dtype=tf.float32), 0.0)
                 new_fragment = tf.less(tf.random_uniform([batch_size], 0, 1, dtype=tf.float32), 0.05)
             else:
                 raise NotImplementedError("invalid mode: %s. Available modes: [SAMPLE, GREEDY, CUSTOM]" % mode)
