@@ -36,6 +36,7 @@ class FeatureUtil:
 
                     序列最大长度
     '''
+
     def __init__(self, config):
         self.config = config
         self.maxlen = config['maxlen']
@@ -233,6 +234,7 @@ class FeatureUtil:
         Returns:
             TFRecordDataLoader
         '''
+
         def _parse_exmp(serial_exmp):
             context_features = {
                 "role_id_hash": tf.io.FixedLenFeature([], dtype=tf.int64),
@@ -364,3 +366,16 @@ class FeatureUtil:
             f.create_dataset('user_features_id', data=np.array(user_features_id))
             f.create_dataset('cur_time', data=np.array(cur_time))
             f.create_dataset('pos_label', data=np.array(pos_label))
+
+
+if __name__ == '__main__':
+    a = tf.constant([[0, 0, 0, 0],[0, 0, 1, 2]],dtype=tf.float32)
+    idx = tf.where(a > 0)
+    output = tf.gather_nd(a, idx)
+    output = tf.reshape(output,[2,1])
+    output2 = tf.layers.Dense(10)(output)
+    with tf.Session() as sess:
+        res1 = sess.run(idx)
+        res2 = sess.run(output)
+        print(res1)
+        print(res2)
