@@ -8,11 +8,13 @@ class L20RecSim(RecSim):
     '''
 
     '''
-    def __init__(self, recEnvSrc, model, modelfile, sess, steps=9, batch_size=None, reward_sqr=False, use_rule=False):
+
+    def __init__(self, recEnvSrc, model, modelfile, sess, steps=9, batch_size=None, reward_sqr=False, use_rule=False, fenliu='1'):
         RecSim.__init__(self, recEnvSrc, model, modelfile, steps, batch_size)
         self.sess = sess
         self.reward_sqr = reward_sqr
         self.use_rule = use_rule
+        self.fenliu = fenliu
 
         self.layers = np.zeros([self.steps, self.batch_size], dtype=int) if self.batch_size else np.zeros(self.steps, dtype=int)
         self.paytypes = np.zeros([self.steps, self.batch_size], dtype=int) if self.batch_size else np.zeros(self.steps, dtype=int)
@@ -244,12 +246,16 @@ class L20RecSim(RecSim):
             # endregion
 
             for batch_i in range(self.batch_size):
-                # rewards[batch_i] += [ctr[i][batch_i] * prices[batch_i][i] for i in range(0, 3)]
-                # rewards[batch_i] += [ctr[i][batch_i] * prices[batch_i][i] for i in range(3, 6)]
-                # rewards[batch_i] += [ctr[i][batch_i] * prices[batch_i][i] for i in range(6, 9)]
-                rewards[batch_i] += [(ctr[i][batch_i] * prices[batch_i][i]) ** 0.5 for i in range(0, 3)]
-                rewards[batch_i] += [(ctr[i][batch_i] * prices[batch_i][i]) ** 0.5 for i in range(3, 6)]
-                rewards[batch_i] += [(ctr[i][batch_i] * prices[batch_i][i]) ** 0.5 for i in range(6, 9)]
+                if self.fenliu == '1':
+                    rewards[batch_i] += [ctr[i][batch_i] * prices[batch_i][i] for i in range(0, 3)]
+                    rewards[batch_i] += [ctr[i][batch_i] * prices[batch_i][i] for i in range(3, 6)]
+                    rewards[batch_i] += [ctr[i][batch_i] * prices[batch_i][i] for i in range(6, 9)]
+                elif self.fenliu == '2':
+                    rewards[batch_i] += [(ctr[i][batch_i] * prices[batch_i][i]) ** 0.5 for i in range(0, 3)]
+                    rewards[batch_i] += [(ctr[i][batch_i] * prices[batch_i][i]) ** 0.5 for i in range(3, 6)]
+                    rewards[batch_i] += [(ctr[i][batch_i] * prices[batch_i][i]) ** 0.5 for i in range(6, 9)]
+                else:
+                    raise Error('meiyou fenliu')
                 # rewards[batch_i] += [ctr[9][batch_i] * ctr[i][batch_i] * prices[batch_i][i] for i in range(3, 6)]
                 # rewards[batch_i] += [ctr[10][batch_i] * ctr[i][batch_i] * prices[batch_i][i] for i in range(6, 9)]
 
