@@ -12,8 +12,17 @@ Date: 2019/2/18
 
 from .impala_utils import ImpalaUtils
 
-
 def exec_hive(sqlfiles, ds, conn_type='impala'):
+    """ Processing data through Hive platform and Impala platform.
+
+    Args:
+        sqlfiles (List): list of sql files
+        ds (str): run sql in 'ds' day
+        conn_type (str): 'hive' or 'impala'
+
+    Returns:
+
+    """
     impala_handler = ImpalaUtils('impala')
     hive_handler = ImpalaUtils('hive')
     for sqlfile in sqlfiles:
